@@ -2,8 +2,8 @@
 #'
 #' @export
 #' @keywords internal
-#' @param locale (character) the locale to use. Run
-#' `person_provider_locales()` for locales supported (default: en_US)
+#' @param locale (character) the locale to use. See
+#' `person_provider_locales` for locales supported (default: en_US)
 #' @param messy (logical) make some messy data. Default: `FALSE`
 #' @details
 #' **Methods**
@@ -97,7 +97,7 @@
 #' PersonProvider$new(locale = "de_AT")$render()
 #' PersonProvider$new(locale = "cs_CZ")$render()
 #' PersonProvider$new(locale = "bg_BG")$render()
-#' PersonProvider$new(locale = "dk_DK")$render()
+#' PersonProvider$new(locale = "da_DK")$render()
 PersonProvider <- R6::R6Class(
   'PersonProvider',
   inherit = BaseProvider,
@@ -119,7 +119,7 @@ PersonProvider <- R6::R6Class(
         # check global locales
         super$check_locale(locale)
         # check person provider locales
-        check_locale_(tolower(locale), person_provider_locales)
+        check_locale_(locale, person_provider_locales)
         self$locale <- locale
       } else {
         self$locale <- 'en_US'
@@ -140,10 +140,15 @@ PersonProvider <- R6::R6Class(
           }
         }
       )
-      if (length(grep("last_name", names(dat))) > 1) {
-        tmp <- grep("last_name", names(dat), value = TRUE)
+      if (length(grep("first_names", names(dat))) > 1) {
+        tmp <- grep("first_names", names(dat), value = TRUE)
         nms <- paste(tmp, seq_along(tmp), sep = "")
-        names(dat)[grep("last_name", names(dat))] <- nms
+        names(dat)[grep("first_names", names(dat))] <- nms
+      }
+      if (length(grep("last_names", names(dat))) > 1) {
+        tmp <- grep("last_names", names(dat), value = TRUE)
+        nms <- paste(tmp, seq_along(tmp), sep = "")
+        names(dat)[grep("last_names", names(dat))] <- nms
       }
       whisker::whisker.render(fmt, data = dat)
     },
@@ -270,8 +275,8 @@ PersonProvider <- R6::R6Class(
 #' @export
 #' @rdname PersonProvider
 person_provider_locales <- c(
-  "bg_bg", "fr_fr", "es_es", "en_us", "fa_ir", "dk_dk",
-  "cs_cz", "de_de", "fr_ch", "de_at", "fi_fi", "es_mx",
-  "en_gb", "hr_hr", "it_it", "lv_lv", "ko_kr", "lt_lt",
-  "ne_np", "nl_nl", "no_no", "pl_pl"
+  "bg_BG", "fr_FR", "es_ES", "en_US", "fa_IR", "da_DK",
+  "cs_CZ", "de_DE", "fr_CH", "de_AT", "fi_FI", "es_MX",
+  "en_GB", "hr_HR", "it_IT", "lv_LV", "ko_KR", "lt_LT",
+  "ne_NP", "nl_NL", "no_NO", "pl_PL"
 )
