@@ -2,13 +2,13 @@
 #'
 #' @export
 #' @keywords internal
-#' @param locale (character) the locale to use. Run 
-#' `phone_number_provider_locales()` for locales supported (default: en_US)
+#' @param locale (character) the locale to use. See
+#' `phone_number_provider_locales` for locales supported (default: en_US)
 #' @details
 #' **Methods**
-#' 
+#'
 #' - `render()` - Make a phone number
-#' 
+#'
 #' @format NULL
 #' @usage NULL
 #' @examples
@@ -29,7 +29,7 @@ PhoneNumberProvider <- R6::R6Class(
         # check locale globally supported
         super$check_locale(locale)
         # check job provider locales
-        check_locale_(tolower(locale), phone_number_provider_locales)
+        check_locale_(locale, phone_number_provider_locales)
         self$locale <- locale
       } else {
         self$locale <- 'en_US'
@@ -46,10 +46,10 @@ PhoneNumberProvider <- R6::R6Class(
 #' @export
 #' @rdname PhoneNumberProvider
 phone_number_provider_locales <- c(
-  "en_us", "es_es", "es_mx", "en_gb", "en_ca", "el_gr", "dk_dk",
-  "de_de", "cs_cz", "bs_ba", "bg_bg", "fa_ir", "fi_fi", "fr_ch",
-  "fr_fr", "hi_in", "hr_hr", "hu_hu", "it_it", "ja_jp", "ko_kr",
-  "it_lt", "lv_lv", "ne_np", "nl_be", "nl_nl", "no_no", "pl_pl",
-  "pt_br", "pt_pt", "ru_ru", "sk_sk", "sl_sl", "sv_se", "tr_tr",
-  "uk_ua", "zh_tw"
+  "en_US", "es_ES", "es_MX", "en_GB", "en_CA", "el_GR", "da_DK",
+  "de_DE", "cs_CZ", "bs_BA", "bg_BG", "fa_IR", "fi_FI", "fr_CH",
+  "fr_FR", "hi_IN", "hr_HR", "hu_HU", "it_IT", "ja_JP", "ko_KR",
+  "lt_LT", "lv_LV", "ne_NP", "nl_BE", "nl_NL", "no_NO", "pl_PL",
+  "pt_BR", "pt_PT", "ru_RU", "sk_SK", "sl_SL", "sv_SE", "tr_TR",
+  "uk_UA", "zh_TW"
 )
